Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Option ¶
type Option func(*WriteTool)
Option is a functional option for configuring a WriteTool.
func WithAllowedDirs ¶
WithAllowedDirs sets the allowed base directories for the write tool. Uses ValidatePath semantics; for TOCTOU-safe enforcement prefer WithPathGuard.
func WithMaxWriteBytes ¶
WithMaxWriteBytes sets the maximum number of bytes that can be written.
func WithPathGuard ¶
WithPathGuard installs a PathGuard which bounds writes to its roots.
Click to show internal directories.
Click to hide internal directories.